package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.api.IDeviceManager;
import com.vendor.platform.api.ILanguageManager;
import com.vendor.platform.api.IUIInitial;
import com.vendor.platform.core.IToolManager;
import com.vendor.platform.core.PlatformCoreActivator;
import com.vendor.platform.core.internal.DeviceManager;
import com.vendor.platform.core.internal.PreferenceUtils;
import com.vendor.platform.ui.ToolUtils;
import com.vendor.platform.ui.internal.IUIInitialImpl;
import com.vendor.platform.ui.internal.LanguageManager;
import com.vendor.platform.ui.internal.PerspectiveUtil;
import com.vendor.platform.ui.internal.ToolEntryBarManager;
import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.dynamichelpers.ExtensionTracker;
import org.eclipse.core.runtime.dynamichelpers.IExtensionChangeHandler;
import org.eclipse.core.runtime.dynamichelpers.IExtensionTracker;
import org.eclipse.core.runtime.dynamichelpers.IFilter;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;

public class AbstractUIActivator extends AbstractUIPlugin implements IExtensionChangeHandler {
  public static final int PLATFROM_DISABLE_EVENT = -1;
  
  public static final int TOOL_DISABLE_EVENT = -10;
  
  private ServiceRegistration<ILanguageManager> languageManager;
  
  private ServiceRegistration<IUIInitial> uiInitial;
  
  private IDeviceManager deviceManager;
  
  private static ExtensionTracker tracker;
  
  private static final String TOOL_PLATFORMCONFIGURATION = "Resources/Common/ChipProperties/PlatformConfiguration";
  
  public BundleContext getContext() {
    return getBundle().getBundleContext();
  }
  
  public IDeviceManager getDeviceManager() {
    if (this.deviceManager == null) {
      ServiceReference reference = getContext().getServiceReference(IDeviceManager.class
          .getName());
      this.deviceManager = (IDeviceManager)getContext().getService(reference);
      assert this.deviceManager != null;
    } 
    return this.deviceManager;
  }
  
  protected void onBundleStart(BundleContext context) {
    this.languageManager = context.registerService(ILanguageManager.class, new LanguageManager(), null);
    this.uiInitial = context.registerService(IUIInitial.class, new IUIInitialImpl(), null);
    IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
    IDeviceManager dm = getDeviceManager();
    StateListener.onBundleStart(context, m, dm);
  }
  
  public void addExtension(IExtensionTracker tracker, IExtension extension) {
    updateWelcomeViewAfterExtensionChanged(extension, 1);
  }
  
  public void removeExtension(IExtension extension, Object[] objects) {
    updateWelcomeViewAfterExtensionChanged(extension, 2);
  }
  
  private void updateWelcomeViewAfterExtensionChanged(IExtension extension, int type) {
    if (!extension.isValid())
      return; 
    IConfigurationElement[] configurationElements = extension.getConfigurationElements();
    if (configurationElements != null && configurationElements.length > 0) {
      Map<String, Integer> needUpdatePerspectiveIDS = new HashMap<>();
      IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
      for (IConfigurationElement configurationElement : configurationElements) {
        String perspectiveID = configurationElement.getAttribute("id");
        if (perspectiveID != null && perspectiveID.length() > 0)
          if (perspectiveID.contains("com.vendor"))
            needUpdatePerspectiveIDS.put(perspectiveID, Integer.valueOf(type));  
      } 
      PerspectiveUtil.addPerspectiveToWelcomeView(needUpdatePerspectiveIDS);
    } 
  }
  
  protected void onBundleStop() {
    this.languageManager.unregister();
    this.uiInitial.unregister();
    if (tracker != null) {
      tracker.close();
      tracker = null;
    } 
  }
  
  protected void onWindowOpen() {
    IExtensionRegistry reg = Platform.getExtensionRegistry();
    IExtensionPoint ep = reg.getExtensionPoint("org.eclipse.ui.perspectives");
    IFilter filter = ExtensionTracker.createExtensionPointFilter(ep);
    tracker = new ExtensionTracker(reg);
    tracker.registerHandler(this, filter);
    ToolEntryBarManager.INSTANCE.init();
    StateListener.onWindowOpen();
    IExtension[] extensions = ep.getExtensions();
    for (int i = 0; i < extensions.length; i++)
      addExtension((IExtensionTracker)tracker, extensions[i]); 
  }
  
  private static void loadDefaultChipsListIfNeeded() {
    if (!PreferenceUtils.isAlsoImportedChipListFile())
      try {
        initializeDefaultPreferences();
        PreferenceUtils.updateAlsoImportedChipListFile(true);
      } catch (Exception e) {
        PlatformCoreActivator.log(e);
      }  
  }
  
  private static void initializeDefaultPreferences() {
    File file = new File(ToolUtils.getInstallPath() + "Resources/Common/ChipProperties/PlatformConfiguration");
    if (file.exists()) {
      try {
        DeviceManager instance = (DeviceManager)DeviceManager.getInstance();
        instance.updateDevices(file, false, false);
      } catch (Exception e) {
        PlatformCoreActivator.log(e);
      } 
      PreferenceUtils.updateAlsoImportedChipListFile(true);
    } 
  }
  
  private static File resolveFile(URL url) {
    File source = null;
    try {
      source = new File(FileLocator.toFileURL(url).toURI());
    } catch (Exception e) {
      try {
        source = new File(FileLocator.toFileURL(url).getFile());
      } catch (IOException iOException) {}
    } 
    return source;
  }
}
